@@ -25,13 +25,19 @@ tv.dict <- function(db, tv_home) {
   } else warning('tvwin.set not found')
 }  
 
-first.word <- function (x, i = 1, expr = substitute(x)) {
+first.word <- function (x, i = 1, expr = substitute(x), add.legal=NULL) {
   words <- if(!missing(x)) as.character(x)[1] else as.character(unlist(expr))[1]
-  if (i > 1) stop("i > 1 not implemented")
+  if (i > 2) stop("only first and second word implemented")
   chars <- substring(words, 1:nchar(words), 1:nchar(words))
-  legal.chars <- c(letters, LETTERS, "0", "1", "2", "3", "4", "5", "6", "7", "8", "9")
+  legal.chars <- c(letters, LETTERS, "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", add.legal)
   non.legal.chars <- (1:length(chars))[!chars %in% legal.chars]
-  if (!any(non.legal.chars)) return(words)
-  if (non.legal.chars[1] == 1) return(character(0))
-  substring(words, 1, non.legal.chars[1] - 1)
+  if (i==1 & is.na(non.legal.chars[1])) return(words)
+  if(i==1) return(substring(words, 1, non.legal.chars[1] - 1)) else
+    if(i==2 & length(non.legal.chars) > 0) return(substring(words, non.legal.chars[1], nchar(words))) else return(character(0))
 }
+
+# words <- 'AGRTS;P'
+# words <- 'QUERROB.Tree'
+# add.legal <- c('-',';')
+# (w <- first.word(words, i=1, add.legal = ';'))
+
